'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');
var drei = require('drei');
var three = require('three');

function getFormatString(format) {
  switch (format) {
    case 64:
      return '-64px';

    case 128:
      return '-128px';

    case 256:
      return '-256px';

    case 512:
      return '-512px';

    default:
      return '';
  }
}

var MATCAP_ROOT = 'https://rawcdn.githack.com/emmelleppi/matcaps/9b36ccaaf0a24881a39062d05566c9e92be4aa0d';
var DEFAULT_MATCAP = '0404E8_0404B5_0404CB_3333FC';
function useMatcapTexture(id, format) {
  if (id === void 0) {
    id = 0;
  }

  if (format === void 0) {
    format = 1024;
  }

  var _useState = react.useState({}),
      matcapList = _useState[0],
      setMatcapList = _useState[1];

  var fileHash = react.useMemo(function () {
    if (typeof id === 'string') {
      return id;
    } else if (typeof id === 'number') {
      return matcapList[id];
    }

    return null;
  }, [id, matcapList]);
  var fileName = "" + (fileHash || DEFAULT_MATCAP) + getFormatString(format) + ".png";
  var url = MATCAP_ROOT + "/" + format + "/" + fileName;
  var matcapTexture = drei.useTextureLoader(url);
  react.useEffect(function () {
    fetch(MATCAP_ROOT + "/matcap-list.json").then(function (response) {
      return response.json();
    }).then(function (data) {
      return setMatcapList(data);
    });
  }, [setMatcapList]);
  return [matcapTexture, url];
}

var NORMAL_ROOT = 'https://rawcdn.githack.com/emmelleppi/normal-maps/f24c810fc1d86b5b1e5dfea914b668f70b5f2923';
var DEFAULT_NORMAL = '151_norm.JPG';
function useNormalTexture(id, _ref) {
  if (id === void 0) {
    id = 0;
  }

  var _ref$repeat = _ref.repeat,
      repeat = _ref$repeat === void 0 ? [1, 1] : _ref$repeat,
      _ref$anisotropy = _ref.anisotropy,
      anisotropy = _ref$anisotropy === void 0 ? 1 : _ref$anisotropy,
      _ref$offset = _ref.offset,
      offset = _ref$offset === void 0 ? [0, 0] : _ref$offset;

  var _useState = react.useState({}),
      normalsList = _useState[0],
      setNormalsList = _useState[1];

  var imageName = normalsList[id] || DEFAULT_NORMAL;
  var url = NORMAL_ROOT + "/normals/" + imageName; // @ts-expect-error

  var normalTexture = drei.useTextureLoader(url);
  react.useEffect(function () {
    fetch(NORMAL_ROOT + "/normals.json").then(function (response) {
      return response.json();
    }).then(function (data) {
      return setNormalsList(data);
    });
  }, [setNormalsList]);
  react.useEffect(function () {
    if (!normalTexture) return;
    normalTexture.wrapS = normalTexture.wrapT = three.RepeatWrapping;
    normalTexture.repeat = new three.Vector2(repeat[0], repeat[1]);
    normalTexture.offset = new three.Vector2(offset[0], offset[1]);
    normalTexture.anisotropy = anisotropy;
  }, [normalTexture, anisotropy, repeat, offset]);
  return [normalTexture, url];
}

exports.useMatcapTexture = useMatcapTexture;
exports.useNormalTexture = useNormalTexture;
